==> vue-icon-saas-3.8.0.tgz: package/lib/font-color.js <==
import { svg } from "@xmweb-ui/vue-common";
import { openBlock, createElementBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 21 17",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M7.058 6.94a.223.223 0 0 0-.044-.088L4.232 1.836 3.77 1l-.464.836L.506 6.884a.223.223 0 0 0-.017.039A4.334 4.334 0 0 0 0 8.925C0 11.172 1.69 13 3.77 13c2.077 0 3.768-1.828 3.768-4.075 0-.692-.166-1.377-.48-1.985Z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M14.296 10.288H8.944l-1.536 3.864c-.08.192-.12.352-.12.48 0 .336.488.576 1.464.72.112.016.188.06.228.132a.51.51 0 0 1 .06.252c0 .096-.016.224-.048.384-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036-.32 0-.648.008-.984.024-.336.016-.688.048-1.056.096a1.578 1.578 0 0 1-.048-.384c0-.112.02-.208.06-.288.04-.08.124-.128.252-.144.496-.08.868-.18 1.116-.3.248-.12.428-.308.54-.564L11.872.52c.112-.272.264-.408.456-.408.064 0 .16.016.288.048l5.808 14.352c.096.224.312.4.648.528s.664.216.984.264a.572.572 0 0 1 .228.132c.056.056.084.156.084.3 0 .096-.016.224-.048.384-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.928 0c-.576.024-1.096.052-1.56.084a2.065 2.065 0 0 1-.048-.384c0-.144.028-.244.084-.3.056-.056.108-.084.156-.084.416-.08.752-.172 1.008-.276.256-.104.384-.26.384-.468a.93.93 0 0 0-.096-.36l-1.512-3.96Zm-.384-.984-2.232-5.88-2.328 5.88h4.56Z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_4 = [_hoisted_2, _hoisted_3];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, _hoisted_4);
}
var FontColor = {
  render
};
var IconFontColor = svg({
  name: "IconFontColor",
  component: FontColor
});
export {
  IconFontColor as default
};

==> vue-icon-saas-3.22.2.tgz: package/lib/font-color.js <==
import { svg } from "@opentinyvue/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 21 17",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M7.058 6.94a.223.223 0 0 0-.044-.088L4.232 1.836 3.77 1l-.464.836L.506 6.884a.223.223 0 0 0-.017.039A4.334 4.334 0 0 0 0 8.925C0 11.172 1.69 13 3.77 13c2.077 0 3.768-1.828 3.768-4.075 0-.692-.166-1.377-.48-1.985Z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "path",
  {
    d: "M14.296 10.288H8.944l-1.536 3.864c-.08.192-.12.352-.12.48 0 .336.488.576 1.464.72.112.016.188.06.228.132a.51.51 0 0 1 .06.252c0 .096-.016.224-.048.384-.432-.032-.888-.06-1.368-.084-.48-.024-.952-.036-1.416-.036-.32 0-.648.008-.984.024-.336.016-.688.048-1.056.096a1.578 1.578 0 0 1-.048-.384c0-.112.02-.208.06-.288.04-.08.124-.128.252-.144.496-.08.868-.18 1.116-.3.248-.12.428-.308.54-.564L11.872.52c.112-.272.264-.408.456-.408.064 0 .16.016.288.048l5.808 14.352c.096.224.312.4.648.528s.664.216.984.264a.572.572 0 0 1 .228.132c.056.056.084.156.084.3 0 .096-.016.224-.048.384-.512-.032-1.016-.06-1.512-.084a28.904 28.904 0 0 0-2.928 0c-.576.024-1.096.052-1.56.084a2.065 2.065 0 0 1-.048-.384c0-.144.028-.244.084-.3.056-.056.108-.084.156-.084.416-.08.752-.172 1.008-.276.256-.104.384-.26.384-.468a.93.93 0 0 0-.096-.36l-1.512-3.96Zm-.384-.984-2.232-5.88-2.328 5.88h4.56Z"
  },
  null,
  -1
  /* HOISTED */
);
var _hoisted_4 = [_hoisted_2, _hoisted_3];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_4));
}
var FontColor = {
  render
};
var index = function index2() {
  return svg({
    name: "IconFontColor",
    component: FontColor
  })();
};
export {
  index as default
};
